pub struct ComplianceClient { /* private fields */ }Expand description
Async HTTP client for the Circle W3S Compliance Engine API.
Implementations
Sourceimpl ComplianceClient
impl ComplianceClient
Sourcepub fn new(api_key: impl Into<String>) -> Self
pub fn new(api_key: impl Into<String>) -> Self
Creates a new client using the Circle production base URL.
Sourcepub fn with_base_url(
api_key: impl Into<String>,
base_url: impl Into<String>,
) -> Self
pub fn with_base_url( api_key: impl Into<String>, base_url: impl Into<String>, ) -> Self
Creates a new client with a custom base URL (useful for Prism mock servers).
Sourcepub async fn screen_address(
&self,
req: &ScreenAddressRequest,
) -> Result<BlockchainAddressScreeningResponse, Error>
pub async fn screen_address( &self, req: &ScreenAddressRequest, ) -> Result<BlockchainAddressScreeningResponse, Error>
Screen a blockchain address for compliance risk.
This is an idempotent operation: repeating the same idempotency_key
returns the original response without re-running the screening.